aboutsummaryrefslogtreecommitdiff
path: root/libbuild2/build/script/parser.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'libbuild2/build/script/parser.hxx')
-rw-r--r--libbuild2/build/script/parser.hxx15
1 files changed, 8 insertions, 7 deletions
diff --git a/libbuild2/build/script/parser.hxx b/libbuild2/build/script/parser.hxx
index 1328bae..3121320 100644
--- a/libbuild2/build/script/parser.hxx
+++ b/libbuild2/build/script/parser.hxx
@@ -174,17 +174,18 @@ namespace build2
}
// If the diag argument is true, then execute the preamble including
// the (trailing) diagnostics line and return the resulting names (see
// exec_special() for the diagnostics line execution semantics).
// Otherwise, execute the preamble excluding the diagnostics line and
// return an empty names list. If requested, call the runner's enter()
// and leave() functions that initialize/clean up the environment
// before/after the preamble execution.
//
// Note: having both root and base scopes for testing (where we pass
// global scope for both).
//
- names
+ pair<names, location>
execute_diag_preamble (const scope& root, const scope& base,
environment&, const script&, runner&,
bool diag, bool enter, bool leave);
@@ -174,17 +174,18 @@ namespace build2
}
// If the diag argument is true, then execute the preamble including
- // the (trailing) diagnostics line and return the resulting names (see
- // exec_special() for the diagnostics line execution semantics).
- // Otherwise, execute the preamble excluding the diagnostics line and
- // return an empty names list. If requested, call the runner's enter()
- // and leave() functions that initialize/clean up the environment
- // before/after the preamble execution.
+ // the (trailing) diagnostics line and return the resulting names and
+ // its location (see exec_special() for the diagnostics line execution
+ // semantics). Otherwise, execute the preamble excluding the
+ // diagnostics line and return an empty names list and location. If
+ // requested, call the runner's enter() and leave() functions that
+ // initialize/clean up the environment before/after the preamble
+ // execution.
//
// Note: having both root and base scopes for testing (where we pass